/**
 * JWT authentication module
 */
import { AbstractAuth, IAuthIdentity, IAccessDetails, GenericResult, IAuthData, IAuthOptions, IAuthIdentityOptions } from "@skazska/abstract-service-model";
import { SignOptions, VerifyOptions } from "jsonwebtoken";
/**
 * JWT Auth constructor module
 */
export interface IJWTAuthOptions extends IAuthOptions {
}
export declare class JWTAuth extends AbstractAuth {
    /**
     * @param identityConstructor
     * @param options
     */
    constructor(identityConstructor: (subject: string, details: IAccessDetails, options?: IAuthIdentityOptions) => IAuthIdentity, options?: IJWTAuthOptions);
    /**
     * checks token and returns auth data
     * @param secret - secret to use
     * @param token - token
     * @param options
     */
    protected verify(secret: any, token: string, options?: VerifyOptions): Promise<GenericResult<IAuthData>>;
    /**
     * generates token
     * @param details - auth details
     * @param subject - subject
     * @param options
     */
    grant(details: any, subject: string, options?: SignOptions): Promise<GenericResult<string>>;
}
